<?php

namespace Drupal\botlog\Commands;

use Drupal\botlog\BotlogHelper;
use Drush\Commands\DrushCommands;
use Drupal\Core\StringTranslation\TranslationManager;

/**
 * A drush command to...
 */
class BotlogCmd extends DrushCommands {

  /**
   * The default expiration on entries.
   *
   * @var int
   */
  protected const DEFAULT_EXPIRE = 3600;

  /**
   * The helper.
   *
   * @var Drupal\botlog\BotlogHelper
   */
  protected $helper;

  /**
   * The IP address.
   *
   * @var string
   */
  protected $ip;

  /**
   * The translation manger.
   *
   * @var Drupal\Core\StringTranslation\TranslationManager
   */
  protected $langMgr;

  /**
   * The unix timestamp.
   *
   * @var int
   */
  protected $timestamp;

  /**
   * The drush command constructor.
   *
   * @param Drupal\botlog\BotlogHelper $helper
   *   The helper.
   * @param Drupal\Core\StringTranslation\TranslationManager $langMgr
   *   The translation manger.
   */
  public function __construct(BotlogHelper $helper, TranslationManager $langMgr) {
    $this->helper = $helper;
    $this->ip = '';
    $this->langMgr = $langMgr;
    $this->timestamp = time() - static::DEFAULT_EXPIRE;
  }

  /**
   * Trim events.
   *
   * @param array $options
   *   Optional timestamp and IP.
   *
   * @usage botlog:trim
   *   Delete older entries.
   *
   * @command botlog:trim
   */
  public function logTrim($options = ['ip' => '', 'timestamp' => 0]) {
    $this->ip = !empty($options['ip']) ? $options['ip'] : '';
    $this->timestamp = !empty($options['timestamp']) ? $options['timestamp'] : $this->timestamp;

    $rows = !empty($this->ip) ? $this->helper->deleteByIp($this->ip) : $this->helper->deleteByTime($this->timestamp);

    print $this->langMgr->formatPlural($rows, "\nOne row deleted.\n", "\n@count rows deleted.\n");
  }

}
