<?php

namespace Drupal\botlog\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\botlog\BotlogHelper;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * IP search form.
 */
class BotlogBanIpForm extends FormBase {

  /**
   * Report helper.
   *
   * @var Drupal\botlog\BotlogHelper
   */
  protected $helper;

  /**
   * Class constructor.
   *
   * @param Drupal\botlog\BotlogHelper $helper
   *   The report helper.
   */
  public function __construct(BotlogHelper $helper) {
    $this->helper = $helper;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $c) {
    return new static($c->get('botlog.helper'), $c->get('botlog.sql'), NULL);
  }

  /**
   * The form ID.
   *
   * @return string
   *   The form ID.
   */
  public function getFormId() {
    return 'botlog_ban';
  }

  /**
   * The bot list.
   *
   * @param array $form
   *   A drupal form array.
   * @param Drupal\Core\Form\FormStateInterface $form_state
   *   A Drupal form state object.
   *
   * @return array
   *   A Drupal form array.
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['ip'] = [
      '#title'         => $this->t('Ban IP'),
      '#description'   => $this->t('Add IP to permanently banned IPs.'),
      '#type'          => 'textfield',
      '#required'      => TRUE,
      '#weight'        => 10,
    ];
    $form['submit'] = [
      '#type'   => 'submit',
      '#value'  => $this->t('Submit'),
      '#weight' => 20,
    ];
    return $form;
  }

  /**
   * Custom submit.
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->helper->banIp(trim($form_state->getValue('ip')), 'Manually set');
  }

  /**
   * Custom validation.
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    if (!$this->helper->fullIp($form_state->getValue('ip'))) {
      $form_state->setErrorByName('ip', $this->t('The IP must be in the form of "xxx.xxx.xxx.xxx". Where xxx is a number from 0 to 255 no leading zeros.'));
    }
  }

}
