<?php

namespace Drupal\botlog\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Routing\RedirectDestinationInterface;
use Drupal\Core\Url;
use Drupal\botlog\BotlogSql;
use Drupal\botlog\BotlogHelper;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * IP search form.
 */
class BotlogDeleteEntry extends FormBase {

  /**
   * Report helper.
   *
   * @var Drupal\botlog\BotlogHelper
   */
  protected $helper;

  /**
   * Redirect.
   *
   * @var Drupal\Core\Routing\RedirectDestinationInterface
   */
  protected $redirect;

  /**
   * Report SQL.
   *
   * @var Drupal\botlog\BotlogSql
   */
  protected $sql;

  /**
   * Class constructor.
   *
   * @param Drupal\botlog\BotlogHelper $helper
   *   The report helper.
   * @param Drupal\botlog\BotlogSql $sql
   *   The reports SQL.
   * @param \Drupal\Core\Routing\RedirectDestinationInterface $redirect
   *   The redirect destination.
   */
  public function __construct(BotlogHelper $helper, BotlogSql $sql, RedirectDestinationInterface $redirect) {
    $this->helper = $helper;
    $this->redirect = $redirect;
    $this->sql = $sql;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $c) {
    return new static($c->get('botlog.helper'), $c->get('botlog.sql'), $c->get('redirect.destination'));
  }

  /**
   * The form ID.
   *
   * @return string
   *   The form ID.
   */
  public function getFormId() {
    return 'botlog_delete';
  }

  /**
   * The bot list.
   *
   * @param array $form
   *   A drupal form array.
   * @param Drupal\Core\Form\FormStateInterface $form_state
   *   A Drupal form state object.
   * @param int $bid
   *   The bot entry ID.
   *
   * @return array
   *   A Drupal form array.
   */
  public function buildForm(array $form, FormStateInterface $form_state, $bid = 0) {
    $error = $bid ? $this->sql->selectEvent($bid) : '';
    $txt = !empty($error) ? print_r($error, TRUE) : 'No information found.';

    $form['bid'] = [
      '#type'          => 'hidden',
      '#value'         => $bid,
      '#required'      => TRUE,
      '#weight'        => 0,
    ];
    $form['submit'] = [
      '#type'   => 'submit',
      '#value'  => $this->t('Delete'),
      '#weight' => 10,
    ];
    $form['txt'] = [
      '#title'         => $this->t('Delete Entry'),
      '#description'   => $this->t('...'),
      '#type'          => 'markup',
      '#markup'        => "<pre>$txt</pre>",
      '#weight'        => 20,
    ];
    return $form;
  }

  /**
   * Custom submit.
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->sql->deleteById(trim($form_state->getValue('bid')));
    $form_state->setRedirectUrl(Url::fromUri('internal:/admin/reports/botlog/monitor'));
  }

  /**
   * Custom submit.
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    if (!preg_match('/^\d+$/', trim($form_state->getValue('bid')))) {
      $form_state->setErrorByName('bid', $this->t('The bot ID must be provided.'));
    }
  }

}
